==> react-image-placeholder-2.8.0.tgz: package/lib/index.js <==
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { filterObjectKeys } from './libs';

var ImagePlaceholder =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(ImagePlaceholder, _Component);

  function ImagePlaceholder() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      imageLoaded: false,
      error: false
    };

    _this.onLoad = function () {
      _this.setState({
        imageLoaded: true
      });

      _this.props.onLoad && _this.props.onLoad();
    };

    _this.onError = function () {
      _this.setState({
        imageLoaded: false,
        error: true
      });

      _this.props.onError && _this.props.onError();
    };

    return _this;
  }

  var _proto = ImagePlaceholder.prototype;

  _proto._renderPlaceholder = function _renderPlaceholder() {
    return React.createElement("img", Object.assign({}, this.props.placeholder, {
      className: ImagePlaceholder.IMAGE_CLASS
    }));
  }
  /**
   * onLoad & onError are intercepted as we need the state handling functions
   * to do our magic
   */
  ;

  _proto._renderFallback = function _renderFallback() {
    var _this2 = this;

    return React.createElement("img", Object.assign({
      className: this._imageClassNames,
      onLoad: function onLoad() {
        return _this2.onLoad();
      },
      onError: function onError() {
        return _this2.onError();
      }
    }, this.props.fallback));
  };

  _proto.render = function render() {
    var _this3 = this;

    var _this$props = this.props,
        fallback = _this$props.fallback,
        imgSources = _this$props.imgSources;
    return React.createElement("div", {
      className: this._classNames
    }, this.state.error ? fallback && this._renderFallback() : React.createElement("picture", null, imgSources.map(function (source, idx) {
      return React.createElement("source", {
        key: idx,
        media: source.media,
        srcSet: source.srcset
      });
    }), React.createElement("img", Object.assign({
      className: this._imageClassNames,
      onLoad: function onLoad() {
        return _this3.onLoad();
      },
      onError: function onError() {
        return _this3.onError();
      }
    }, this._imageProps))), this.state.imageLoaded || this._renderPlaceholder());
  };

  _createClass(ImagePlaceholder, [{
    key: "_classNames",
    get: function get() {
      var _this$props2 = this.props,
          className = _this$props2.className,
          rounded = _this$props2.rounded;
      return classnames(ImagePlaceholder.CLASSNAME, className, rounded && ImagePlaceholder.CLASSNAME + "--rounded");
    }
  }, {
    key: "_imageClassNames",
    get: function get() {
      return classnames(ImagePlaceholder.IMAGE_CLASS, this.state.imageLoaded || ImagePlaceholder.IMAGE_CLASS + "--hidden");
    }
  }, {
    key: "_imageProps",
    get: function get() {
      var imageProps = Object.keys(htmlImgProps);
      return filterObjectKeys(this.props, imageProps);
    }
  }]);

  return ImagePlaceholder;
}(Component);

ImagePlaceholder.IMAGE_CLASS = 'sui-ImagePlaceholder-image';
ImagePlaceholder.CLASSNAME = 'sui-ImagePlaceholder';
ImagePlaceholder.displayName = 'ImagePlaceholder';
/**
 * <img> props, https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img
 */

var htmlImgProps = {
  alt: PropTypes.string.isRequired,
  crossorigin: PropTypes.string,
  height: PropTypes.string,
  ismap: PropTypes.bool,
  longdesc: PropTypes.string,
  referrerpolicy: PropTypes.string,
  sizes: PropTypes.string,
  src: PropTypes.string.isRequired,
  srcset: PropTypes.string,
  usemap: PropTypes.string,
  width: PropTypes.string
};
ImagePlaceholder.defaultProps = {
  imgSources: []
};
export default ImagePlaceholder;

==> react-image-placeholder-2.9.0.tgz: package/lib/index.js <==
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import { filterObjectKeys } from './libs';

var ImagePlaceholder = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ImagePlaceholder, _Component);

  function ImagePlaceholder() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.state = {
      imageLoaded: false,
      error: false
    };

    _this.onLoad = function () {
      _this.setState({
        imageLoaded: true
      });

      _this.props.onLoad && _this.props.onLoad();
    };

    _this.onError = function () {
      _this.setState({
        imageLoaded: false,
        error: true
      });

      _this.props.onError && _this.props.onError();
    };

    return _this;
  }

  var _proto = ImagePlaceholder.prototype;

  _proto._renderPlaceholder = function _renderPlaceholder() {
    return React.createElement("img", Object.assign({}, this.props.placeholder, {
      className: ImagePlaceholder.IMAGE_CLASS
    }));
  }
  /**
   * onLoad & onError are intercepted as we need the state handling functions
   * to do our magic
   */
  ;

  _proto._renderFallback = function _renderFallback() {
    var _this2 = this;

    return React.createElement("img", Object.assign({
      className: this._imageClassNames,
      onLoad: function onLoad() {
        return _this2.onLoad();
      },
      onError: function onError() {
        return _this2.onError();
      }
    }, this.props.fallback));
  };

  _proto.render = function render() {
    var _this3 = this;

    var _this$props = this.props,
        fallback = _this$props.fallback,
        imgSources = _this$props.imgSources;
    return React.createElement("div", {
      className: this._classNames
    }, this.state.error ? fallback && this._renderFallback() : React.createElement("picture", null, imgSources.map(function (source, idx) {
      return React.createElement("source", {
        key: idx,
        media: source.media,
        srcSet: source.srcset
      });
    }), React.createElement("img", Object.assign({
      className: this._imageClassNames,
      onLoad: function onLoad() {
        return _this3.onLoad();
      },
      onError: function onError() {
        return _this3.onError();
      }
    }, this._imageProps))), this.state.imageLoaded || this._renderPlaceholder());
  };

  _createClass(ImagePlaceholder, [{
    key: "_classNames",
    get: function get() {
      var _this$props2 = this.props,
          className = _this$props2.className,
          rounded = _this$props2.rounded;
      return classnames(ImagePlaceholder.CLASSNAME, className, rounded && ImagePlaceholder.CLASSNAME + "--rounded");
    }
  }, {
    key: "_imageClassNames",
    get: function get() {
      return classnames(ImagePlaceholder.IMAGE_CLASS, this.state.imageLoaded || ImagePlaceholder.IMAGE_CLASS + "--hidden");
    }
  }, {
    key: "_imageProps",
    get: function get() {
      var imageProps = Object.keys(htmlImgProps);
      return filterObjectKeys(this.props, imageProps);
    }
  }]);

  return ImagePlaceholder;
}(Component);

ImagePlaceholder.IMAGE_CLASS = 'sui-ImagePlaceholder-image';
ImagePlaceholder.CLASSNAME = 'sui-ImagePlaceholder';
ImagePlaceholder.displayName = 'ImagePlaceholder';
/**
 * <img> props, https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img
 */

var htmlImgProps = {
  alt: PropTypes.string.isRequired,
  crossorigin: PropTypes.string,
  height: PropTypes.string,
  ismap: PropTypes.bool,
  longdesc: PropTypes.string,
  referrerpolicy: PropTypes.string,
  sizes: PropTypes.string,
  src: PropTypes.string.isRequired,
  srcset: PropTypes.string,
  usemap: PropTypes.string,
  width: PropTypes.string
};
ImagePlaceholder.defaultProps = {
  imgSources: []
};
export default ImagePlaceholder;
